boomerang package
=================

Submodules
----------

boomerang.messages module
-------------------------

.. automodule:: boomerang.messages
    :members:
    :undoc-members:
    :show-inheritance:

boomerang.messenger module
--------------------------

.. automodule:: boomerang.messenger
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: boomerang
    :members:
    :undoc-members:
    :show-inheritance:
